# Generated by Django 4.1.1 on 2022-11-09 12:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('qrtoolkit_core', '0013_auto_20220822_0754'),
    ]

    operations = [
        migrations.AlterField(
            model_name='qrcode',
            name='title',
            field=models.CharField(blank=True, default='', max_length=100),
        ),
    ]
