# Generated by Django 3.0.11 on 2021-04-14 14:50

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('qrtoolkit_core', '0002_auto_20210202_1257'),
    ]

    operations = [
        migrations.AddField(
            model_name='department',
            name='users',
            field=models.ManyToManyField(related_name='departments', to=settings.AUTH_USER_MODEL),
        ),
    ]
