# Generated by Django 3.0.11 on 2022-08-22 07:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('qrtoolkit_core', '0012_qrcode_kiosk_introduction'),
    ]

    operations = [
        migrations.AlterField(
            model_name='qrcode',
            name='kiosk_introduction',
            field=models.TextField(blank=True, default='', null=True),
        ),
    ]
