# Generated by Django 3.0.11 on 2021-09-29 16:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('qrtoolkit_core', '0009_linkurl_visible'),
    ]

    operations = [
        migrations.AlterField(
            model_name='linkurl',
            name='visible',
            field=models.BooleanField(blank=True, default=True, help_text='Sets the visibility for this link in KIOSK mode.', null=True),
        ),
    ]
