# Generated by Django 3.0.11 on 2022-02-24 15:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('qrtoolkit_core', '0010_auto_20210929_1616'),
    ]

    operations = [
        migrations.AlterField(
            model_name='linkurl',
            name='url',
            field=models.URLField(blank=True, default='', help_text='redirect to external page', max_length=800),
        ),
    ]
